R/rgamer.R
rgamer.Rd
The rgamer package provides useful functions to highlight some important aspects of basic games. It visually displays the game and finds solutions of the games.
Useful links:
https://yukiyanai.github.io/rgamer/
https://github.com/yukiyanai/rgamer
Yoshio Kamijo and Yuki Yanai yanai.yuki@kochi-tech.ac.jp